@@ -49,25 +49,27 @@ def validInput(inputs: list, ffmpeg, args, log) -> list:
 
             # Throw error if file referenced doesn't exist.
             if(not os.path.isfile(myInput)):
-                log.error(f"{myInput} doesn't exist!")
+                log.error("{} doesn't exist!".format(myInput))
 
             # Check if the file format is valid.
             fileFormat = myInput[myInput.rfind('.'):]
 
             if('.' not in fileFormat):
-                log.error('File must have extension.')
+                log.error('File must have an extension.')
 
             if(fileFormat in invalidExtensions):
                 log.error(f'Invalid file extension "{fileFormat}" for {myInput}')
             inputList.append(myInput)
 
         elif(myInput.startswith('http://') or myInput.startswith('https://')):
-            basename = re.sub(r'\W+', '-', myInput)
+            outtmpl = re.sub(r'\W+', '-', myInput)
+
+            if(outtmpl.endswith('-mp4')):
+                outtmpl = outtmpl[:-4]
+            outtmpl += '.mp4'
 
-            outtmpl = basename
             if(args.output_dir is not None):
-                from usefulFunctions import sep
-                outtmpl = args.output_dir + sep() + basename
+                outtmpl = os.path.join(args.output_dir, outtmpl)
 
             try:
                 import youtube_dl
@@ -75,17 +77,15 @@ def validInput(inputs: list, ffmpeg, args, log) -> list:
                 log.error('Download the youtube-dl python library to download URLs.\n' \
                     '   pip3 install youtube-dl')
 
-            from usefulFunctions import ProgressBar
+            from auto_editor.usefulFunctions import ProgressBar
 
-            if(not os.path.isfile(outtmpl + '.mp4')):
+            if(not os.path.isfile(outtmpl)):
 
                 ytbar = ProgressBar(100, 'Downloading')
                 def my_hook(d):
                     nonlocal ytbar
                     if(d['status'] == 'downloading'):
-                        p = d['_percent_str']
-                        p = p.replace('%','')
-                        ytbar.tick(float(p))
+                        ytbar.tick(float(d['_percent_str'].replace('%','')))
 
                 ydl_opts = {
                     'nocheckcertificate': not args.check_certificate,
@@ -105,7 +105,7 @@ def validInput(inputs: list, ffmpeg, args, log) -> list:
 
                 log.conwrite('')
 
-            inputList.append(outtmpl + '.mp4')
+            inputList.append(outtmpl)
         else:
             log.error('Could not find file: ' + myInput)
 
